diff --git a/doc/dox/jkqtplotter.dox b/doc/dox/jkqtplotter.dox
index 0d7114fe5f..3528c7b42d 100644
--- a/doc/dox/jkqtplotter.dox
+++ b/doc/dox/jkqtplotter.dox
@@ -24,7 +24,7 @@ This group assembles a variety of mathematical tool functions that are used in d
Functions in this group form the basis for the statistics (\ref jkqtptools_math_statistics ) and linear algebra libraries (\ref jkqtptools_math_linalg ), by providing allocation and freeing of (aligned) memory arrays.
-\seeJKQTPlotterBasicJKQTPDatastoreStatistics
+\see JKQTPlotterBasicJKQTPDatastoreStatistics
\defgroup jkqtptools_math_linalg Linear Algebra Tools
\ingroup jkqtptools_math
@@ -42,6 +42,7 @@ This group contains a statistics library, which offers several basic methods and
- \ref jkqtptools_math_statistics_1dkde
- \ref jkqtptools_math_statistics_2dkde
.
+In addition there is a set of "adaptors" (see \ref jkqtptools_math_statistics_adaptors ) that shortcut the calculation of a statistical property and the subsequent parametrization of a plot with the results. With these adaptors you can add e.g. a boxplot or histogram chart to a plot by calling only one function.
All statistics functions use an iterator-based interface, comparable to the interface of the algorithms in the C++ standard template library. To this end, the class `JKQTPDatastore` provides an iterator interface to its columns, using the functions `JKQTPDatastore::begin()` and `JKQTPDatastore::end()`. Both functions simply receive the column ID as parameter and exist in a const and a mutable variant. the latter allows to also edit the data. In addition the function `JKQTPDatastore::backInserter()` returns a back-inserter iterator (like generated for STL containers with `std::back_inserter(container)`) that also allows to append to the column.
@@ -80,6 +81,9 @@ All statistics functions use all values in the given range and convert each valu
\defgroup jkqtptools_math_statistics_2dkde 2-dimensional Kernel Density Estimates
\ingroup jkqtptools_math_statistics
+\defgroup jkqtptools_math_statistics_adaptors Statistics To Plot Adaptors
+\ingroup jkqtptools_math_statistics
+
\defgroup jkqtptools_string String/String-Conversion Tool Functions
@@ -360,6 +364,8 @@ This group assembles graphs that show their data with symbols and optionally wit
JKQTPBoxplotVerticalGraph, JKQTPBoxplotHorizontalGraph
+\see \ref jkqtptools_math_statistics_adaptors for shortcuts to calculate statistical properties of data and then adding a plot with the results.
+
\defgroup jkqtplotter_geoplots Geometric Elements (Lines, Rectangles, ...)
\ingroup jkqtplotter_graphsgroup
diff --git a/doc/dox/whatsnew.dox b/doc/dox/whatsnew.dox
index 31cb734e34..dd8a64fda7 100644
--- a/doc/dox/whatsnew.dox
+++ b/doc/dox/whatsnew.dox
@@ -44,7 +44,7 @@ Changes, compared to \ref page_whatsnew_V2018_08 "v2018.08" include:
new: advanced styling options for boxplots + example for the styling: \ref JKQTPlotterBoxplotStyling
new: notched boxplots, see: \ref JKQTPlotterBoxplotStyling
new: several new plot symbols, see: JKQTPGraphSymbols
- new: Statistics library with functions to calculate histograms, regression, kernel density estimates, ... see: \ref jkqtptools_statistics
+ new: Statistics library with functions to calculate histograms, regression, kernel density estimates, ... see: \ref jkqtptools_math_statistics
new: iterator interface and improved documentation for JKQTPDatastore
changed: removed old selection-code and replaced by general highlighting feature
changed: JKQTPStepHorizontalGraph has been renamed to JKQTPSpecialLineHorizontalGraph (vertical variants also) and have gained additional features (baseline for filling and drawing of symbols)
@@ -58,7 +58,7 @@ Changes, compared to \ref page_whatsnew_V2018_08 "v2018.08" include:
Updates to JKQTMathText:
- - new: slanted fractions (
\sfrac{}{} , \stfrac{}{} )
+ - new: slanted fractions (
\\sfrac{}{} , \\stfrac{}{} )
- update/fix: several general improvements and bugfixes
- update/fix: improved error handling
- update: updated contained version of STIX fonts, better handling of different STIX versions
diff --git a/examples/jkqtfastplotter_test/jkqtfastplotter_test.pro b/examples/jkqtfastplotter_test/jkqtfastplotter_test.pro
index f8d0084a7e..71f562cecf 100644
--- a/examples/jkqtfastplotter_test/jkqtfastplotter_test.pro
+++ b/examples/jkqtfastplotter_test/jkqtfastplotter_test.pro
@@ -37,3 +37,5 @@ CONFIG (debug, debug|release) {
LIBS += -L../../staticlib/jkqtfastplotterlib/release -ljkqtfastplotterlib
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/jkqtmathtext_simpletest/jkqtmathtext_simpletest.pro b/examples/jkqtmathtext_simpletest/jkqtmathtext_simpletest.pro
index 3672a058ad..cf3311b8c5 100644
--- a/examples/jkqtmathtext_simpletest/jkqtmathtext_simpletest.pro
+++ b/examples/jkqtmathtext_simpletest/jkqtmathtext_simpletest.pro
@@ -16,3 +16,6 @@ CONFIG (debug, debug|release) {
LIBS += -L../../staticlib/jkqtplotterlib/release -ljkqtplotterlib
}
message("LIBS = $$LIBS")
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/jkqtmathtext_test/jkqtmathtext_test.pro b/examples/jkqtmathtext_test/jkqtmathtext_test.pro
index e1b0095f3b..88a033c7ea 100644
--- a/examples/jkqtmathtext_test/jkqtmathtext_test.pro
+++ b/examples/jkqtmathtext_test/jkqtmathtext_test.pro
@@ -45,3 +45,6 @@ CONFIG (debug, debug|release) {
LIBS += -L../../staticlib/jkqtmathtextlib/release -ljkqtmathtextlib
}
message("LIBS = $$LIBS")
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_barchart/jkqtplotter_simpletest_barchart.pro b/examples/simpletest_barchart/jkqtplotter_simpletest_barchart.pro
index c09d633f9d..74e6f96e4c 100644
--- a/examples/simpletest_barchart/jkqtplotter_simpletest_barchart.pro
+++ b/examples/simpletest_barchart/jkqtplotter_simpletest_barchart.pro
@@ -20,6 +20,8 @@ CONFIG (debug, debug|release) {
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_boxplot/jkqtplotter_simpletest_boxplot.pro b/examples/simpletest_boxplot/jkqtplotter_simpletest_boxplot.pro
index 5ab3e217bf..bfac3ea3d2 100644
--- a/examples/simpletest_boxplot/jkqtplotter_simpletest_boxplot.pro
+++ b/examples/simpletest_boxplot/jkqtplotter_simpletest_boxplot.pro
@@ -21,5 +21,7 @@ message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_contourplot/jkqtplotter_simpletest_contourplot.pro b/examples/simpletest_contourplot/jkqtplotter_simpletest_contourplot.pro
index afd8f2ce50..12c126b29a 100644
--- a/examples/simpletest_contourplot/jkqtplotter_simpletest_contourplot.pro
+++ b/examples/simpletest_contourplot/jkqtplotter_simpletest_contourplot.pro
@@ -23,6 +23,8 @@ message("LIBS = $$LIBS")
HEADERS += \
contourplotanimator.h
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_dateaxes/jkqtplotter_simpletest_dateaxes.pro b/examples/simpletest_dateaxes/jkqtplotter_simpletest_dateaxes.pro
index 77818dd4e3..1b82cf0698 100644
--- a/examples/simpletest_dateaxes/jkqtplotter_simpletest_dateaxes.pro
+++ b/examples/simpletest_dateaxes/jkqtplotter_simpletest_dateaxes.pro
@@ -21,6 +21,8 @@ message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_errorbarstyles/jkqtplotter_simpletest_errorbarstyles.pro b/examples/simpletest_errorbarstyles/jkqtplotter_simpletest_errorbarstyles.pro
index 2a5b4f93d7..fdfa80f457 100644
--- a/examples/simpletest_errorbarstyles/jkqtplotter_simpletest_errorbarstyles.pro
+++ b/examples/simpletest_errorbarstyles/jkqtplotter_simpletest_errorbarstyles.pro
@@ -20,5 +20,7 @@ CONFIG (debug, debug|release) {
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_filledgraphs/jkqtplotter_simpletest_filledgraphs.pro b/examples/simpletest_filledgraphs/jkqtplotter_simpletest_filledgraphs.pro
index 52f7315052..60520a91ef 100644
--- a/examples/simpletest_filledgraphs/jkqtplotter_simpletest_filledgraphs.pro
+++ b/examples/simpletest_filledgraphs/jkqtplotter_simpletest_filledgraphs.pro
@@ -22,6 +22,8 @@ CONFIG (debug, debug|release) {
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_geometric/jkqtplotter_simpletest_geometric.pro b/examples/simpletest_geometric/jkqtplotter_simpletest_geometric.pro
index 4069f295b5..aeab4bd4c9 100644
--- a/examples/simpletest_geometric/jkqtplotter_simpletest_geometric.pro
+++ b/examples/simpletest_geometric/jkqtplotter_simpletest_geometric.pro
@@ -19,6 +19,8 @@ CONFIG (debug, debug|release) {
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_imageplot/jkqtplotter_simpletest_imageplot.pro b/examples/simpletest_imageplot/jkqtplotter_simpletest_imageplot.pro
index 94c93174c1..8e9f4764d2 100644
--- a/examples/simpletest_imageplot/jkqtplotter_simpletest_imageplot.pro
+++ b/examples/simpletest_imageplot/jkqtplotter_simpletest_imageplot.pro
@@ -19,6 +19,8 @@ CONFIG (debug, debug|release) {
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_imageplot_modifier/jkqtplotter_simpletest_imageplot_modifier.pro b/examples/simpletest_imageplot_modifier/jkqtplotter_simpletest_imageplot_modifier.pro
index 1d55267418..d3be1d43c0 100644
--- a/examples/simpletest_imageplot_modifier/jkqtplotter_simpletest_imageplot_modifier.pro
+++ b/examples/simpletest_imageplot_modifier/jkqtplotter_simpletest_imageplot_modifier.pro
@@ -19,6 +19,8 @@ CONFIG (debug, debug|release) {
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_imageplot_opencv/jkqtplotter_simpletest_imageplot_opencv.pro b/examples/simpletest_imageplot_opencv/jkqtplotter_simpletest_imageplot_opencv.pro
index e3031fbf7e..8d00a29027 100644
--- a/examples/simpletest_imageplot_opencv/jkqtplotter_simpletest_imageplot_opencv.pro
+++ b/examples/simpletest_imageplot_opencv/jkqtplotter_simpletest_imageplot_opencv.pro
@@ -32,3 +32,6 @@ CONFIG (debug, debug|release) {
message("LIBS = $$LIBS")
INSTALLS += opencvdlls
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_logaxes/jkqtplotter_simpletest_logaxes.pro b/examples/simpletest_logaxes/jkqtplotter_simpletest_logaxes.pro
index 7e3eb3fd71..6e76408829 100644
--- a/examples/simpletest_logaxes/jkqtplotter_simpletest_logaxes.pro
+++ b/examples/simpletest_logaxes/jkqtplotter_simpletest_logaxes.pro
@@ -19,6 +19,8 @@ CONFIG (debug, debug|release) {
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_rgbimageplot/jkqtplotter_simpletest_rgbimageplot.pro b/examples/simpletest_rgbimageplot/jkqtplotter_simpletest_rgbimageplot.pro
index adf5ad268b..31753d531f 100644
--- a/examples/simpletest_rgbimageplot/jkqtplotter_simpletest_rgbimageplot.pro
+++ b/examples/simpletest_rgbimageplot/jkqtplotter_simpletest_rgbimageplot.pro
@@ -19,6 +19,8 @@ CONFIG (debug, debug|release) {
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_rgbimageplot_opencv/jkqtplotter_simpletest_rgbimageplot_opencv.pro b/examples/simpletest_rgbimageplot_opencv/jkqtplotter_simpletest_rgbimageplot_opencv.pro
index 77606a34cd..97dd0c0a4e 100644
--- a/examples/simpletest_rgbimageplot_opencv/jkqtplotter_simpletest_rgbimageplot_opencv.pro
+++ b/examples/simpletest_rgbimageplot_opencv/jkqtplotter_simpletest_rgbimageplot_opencv.pro
@@ -35,3 +35,6 @@ CONFIG (debug, debug|release) {
message("LIBS = $$LIBS")
INSTALLS += opencvdlls exampleimg
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_rgbimageplot_qt/jkqtplotter_simpletest_rgbimageplot_qt.pro b/examples/simpletest_rgbimageplot_qt/jkqtplotter_simpletest_rgbimageplot_qt.pro
index caef2e7cd9..f63fb54fc8 100644
--- a/examples/simpletest_rgbimageplot_qt/jkqtplotter_simpletest_rgbimageplot_qt.pro
+++ b/examples/simpletest_rgbimageplot_qt/jkqtplotter_simpletest_rgbimageplot_qt.pro
@@ -22,6 +22,8 @@ CONFIG (debug, debug|release) {
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_stackedbars/jkqtplotter_simpletest_stackedbars.pro b/examples/simpletest_stackedbars/jkqtplotter_simpletest_stackedbars.pro
index 3b04f92edb..7fc97628ba 100644
--- a/examples/simpletest_stackedbars/jkqtplotter_simpletest_stackedbars.pro
+++ b/examples/simpletest_stackedbars/jkqtplotter_simpletest_stackedbars.pro
@@ -21,6 +21,8 @@ CONFIG (debug, debug|release) {
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/simpletest_stepplots/jkqtplotter_simpletest_stepplots.pro b/examples/simpletest_stepplots/jkqtplotter_simpletest_stepplots.pro
index 16d572d589..2d56e01b85 100644
--- a/examples/simpletest_stepplots/jkqtplotter_simpletest_stepplots.pro
+++ b/examples/simpletest_stepplots/jkqtplotter_simpletest_stepplots.pro
@@ -22,6 +22,8 @@ CONFIG (debug, debug|release) {
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/examples/test_distributionplot/test_distributionplot.pro b/examples/test_distributionplot/test_distributionplot.pro
index bbf3fa6857..b75b749cbc 100644
--- a/examples/test_distributionplot/test_distributionplot.pro
+++ b/examples/test_distributionplot/test_distributionplot.pro
@@ -11,6 +11,7 @@ SOURCES = test_distributionplot.cpp
# To fix error: C2338: va_start argument must not
# have reference type and must not be parenthesized
DEFINES += _CRT_NO_VA_START_VALIDATION
+ DEFINES += NOMINMAX
}
# configure Qt
diff --git a/examples/test_styledboxplot/test_styledboxplot.pro b/examples/test_styledboxplot/test_styledboxplot.pro
index 8708da16f4..6bd0eacb02 100644
--- a/examples/test_styledboxplot/test_styledboxplot.pro
+++ b/examples/test_styledboxplot/test_styledboxplot.pro
@@ -19,6 +19,8 @@ CONFIG (debug, debug|release) {
}
message("LIBS = $$LIBS")
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/lib/jkqtcommon/jkqtpbasicimagetools.h b/lib/jkqtcommon/jkqtpbasicimagetools.h
index 7846f12a4f..b038c9982a 100644
--- a/lib/jkqtcommon/jkqtpbasicimagetools.h
+++ b/lib/jkqtcommon/jkqtpbasicimagetools.h
@@ -744,7 +744,7 @@ inline void JKQTPImagePlot_array2image(const T* dbl_in, int width, int height, Q
\param dbl_in pointer to a 1D array of template type \c T representing the image to plot. This array has to be of size \a width * \a height
\param width width of the array in \a dbl
\param height height of the array in \a dbl
- \param[out] im the QImage object to draw to (should be initialized as \c QImage::Format_ARGB32 )
+ \param[out] img the QImage object to draw to (should be initialized as \c QImage::Format_ARGB32 )
\param lutUser user-defined lookup-table
\param lutUserSize number of entries in \a lutUser
\param minColor lower boundary of color range in \a dbl pixels, if \a minColor == \a maxColor then this function will extract the image min and image max.
diff --git a/lib/jkqtcommon/jkqtpdrawingtools.h b/lib/jkqtcommon/jkqtpdrawingtools.h
index 4dd4001954..7fd8a17c5b 100644
--- a/lib/jkqtcommon/jkqtpdrawingtools.h
+++ b/lib/jkqtcommon/jkqtpdrawingtools.h
@@ -187,23 +187,6 @@ inline void JKQTPPlotSymbol(TPainter& painter, double x, double y, JKQTPGraphSym
JKQTP_LIB_EXPORT void JKQTPPlotSymbol(QPaintDevice& paintDevice, double x, double y, JKQTPGraphSymbols symbol, double size, double symbolLineWidth, QColor color, QColor fillColor);
-/*! \brief plot an arrow between positions (x1,y1) and (x2,y2)
- \ingroup jkqtptools_drawing
-
- \param painter the QPainter to draw to
- \param x1 first x-coordinate of the arrow
- \param y1 first y-coordinate of the arrow
- \param x2 second x-coordinate of the arrow
- \param y2 second y-coordinate of the arrow
- \param symbol type of the symbol to plot, see JKQTPGraphSymbols
- \param size size (width/height) of the symbol around (\a x , \a y)
- \param symbolLineWidth width of the lines used to draw the symbol
- \param color color of the symbol lines
- \param fillColor color of the symbol filling
- */
-//JKQTP_LIB_EXPORT void JKQTPPlotArrow(JKQTPEnhancedPainter& painter, int x, int y, JKQTPGraphSymbols symbol, double size, double symbolLineWidth, QColor color, QColor fillColor);
-
-
/*! \brief draw an ellipse without setting pen or brush, or saving the painter!
\ingroup jkqtptools_drawing
@@ -247,7 +230,7 @@ JKQTP_LIB_EXPORT QPolygonF JKQTPCleanPolygon(const QPolygonF& poly, double dista
/** \brief takes a list of QLineF objesct \a lines and tries to combine as many of them as possible to QPolygonF objects.
* Note: This method implements an incomplete algorithm with \a searchMaxSurroundingElements>0, as solving
- * the complete problem is very time-consuming (cubic runtime)
+ * the complete problem is very time-consuming (cubic runtime)
* \ingroup jkqtptools_drawing
*
* \param lines line segments to unify
diff --git a/lib/jkqtcommon/jkqtplinalgtools.h b/lib/jkqtcommon/jkqtplinalgtools.h
index 7958c9b064..8ca6287a11 100644
--- a/lib/jkqtcommon/jkqtplinalgtools.h
+++ b/lib/jkqtcommon/jkqtplinalgtools.h
@@ -83,6 +83,7 @@
* \ingroup jkqtptools_math_linalg
*
* \tparam type of the matrix cells (typically double or float)
+ * \param matrix the matrix to print out
* \param L number of lines/rows in the matrix
* \param C number of columns in the matrix
* \param width width (in characters) of each cell in the output (used for formatting)
@@ -109,6 +110,7 @@ inline void jkqtplinalgPrintMatrix(T* matrix, long L, long C, int width=9, int p
* \ingroup jkqtptools_math_linalg
*
* \tparam type of the matrix cells (typically double or float)
+ * \param matrix the matrix to convert
* \param L number of lines/rows in the matrix
* \param C number of columns in the matrix
* \param width width (in characters) of each cell in the output (used for formatting)
@@ -173,6 +175,7 @@ inline void jkqtplinalgPM1ToRWBColors(double val, uint8_t& r, uint8_t& g, uint8_
* \param[out] r returns the red value (0..255)
* \param[out] g returns the green value (0..255)
* \param[out] b returns the blue value (0..255)
+ * \param gamma a gamma-value for non-linear color scaling
*/
inline void jkqtplinalgPM1ToNonlinRWBColors(double val, uint8_t& r, uint8_t& g, uint8_t& b, double gamma=0.5){
if (val<0) {
@@ -186,6 +189,7 @@ inline void jkqtplinalgPM1ToNonlinRWBColors(double val, uint8_t& r, uint8_t& g,
*
*
* \tparam type of the matrix cells (typically double or float)
+ * \param matrix the matrix to convert
* \param L number of lines/rows in the matrix
* \param C number of columns in the matrix
* \param width width (in characters) of each cell in the output (used for formatting)
@@ -759,8 +763,7 @@ inline bool jkqtplinalgLinSolve(const T* A, T* B, long N, long C) {
\param A an NxN matrix of coefficients
\param b an N-entry vector
- \param N number of equations
- \param C number of columns in B
+ \param N number of rows and columns in \a A
\param[out] result_out a N-entry vector with the result
\return \c true on success
@@ -778,7 +781,7 @@ inline bool jkqtplinalgLinSolve(const T* A, const T* b, long N, T* result_out) {
\param A an NxN matrix of coefficients
\param[in,out] b an N-entry vector (also receives the result)
\param N number of equations
- \param C number of columns in B
+ \param N number of rows and columns in \a A
\return \c true on success
\note This function uses the Gauss-Jordan algorithm
diff --git a/lib/jkqtcommon/jkqtpstatisticstools.h b/lib/jkqtcommon/jkqtpstatisticstools.h
index 67f4536cde..d5cb34619a 100644
--- a/lib/jkqtcommon/jkqtpstatisticstools.h
+++ b/lib/jkqtcommon/jkqtpstatisticstools.h
@@ -304,6 +304,7 @@ inline double jkqtpstatMaximum(InputIt first, InputIt last, InputIt* maxPos=null
\tparam FF a functor type
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
+ \param modifierFunctor the function to apply to each element in the range before summation (of type \a FF )
\param[out] Noutput optionally returns the number of accumulated valid values in this variable
\return Sum of modified data returned between \a first and \a last (excluding invalid doubles).
If the given range \a first ... \a last is empty, 0 is returned
@@ -881,7 +882,6 @@ inline void jkqtpstat5NumberStatisticsOfSortedVector(const TVector& data, double
\tparam TVector a type, compatible with std::vector (i,e, providing size(), []-element access and iterators)
\param data a sorted vector with values
- \param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param outliersout output iterator that receives the outliers, smaller than minimum and larger than maximum
\param[out] minimum optionally returns the minimum value of the array
\param minimumQuantile specifies a quantile for the return value minimum (default is 0 for the real minimum, but you could e.g. use 0.05 for the 5% quantile!)
@@ -1049,7 +1049,7 @@ struct JKQTPStat5NumberStatistics {
double IQR() const;
/** \brief interquartile range, calculated as \f[ 2\cdot\frac{1.58\cdot \mbox{IQR}}{\sqrt{N}} \f] \see https://en.wikipedia.org/wiki/Box_plot */
double IQRSignificanceEstimate() const;
- /** \brief list with the outlier values maximum */
+ /** \brief list with the outlier values < minimum and > maximum */
std::vector outliers;
};
@@ -1711,6 +1711,8 @@ inline void jkqtpstatKDE1DAutoranged(InputIt first, InputIt last, OutputIt KDEXO
\param binsLast iterator pointing behind the last item in the set of KDE bins
\param[out] KDEXOut output iterator that receives x-positions of the KDE bins. Location of this value inside the bin range is defined by \a binXMode
\param[out] KDEYOut output iterator that receives counts/frequencies of the KDE bins
+ \param kernel the kernel function to use (e.g. jkqtpstatKernel1DGaussian() )
+ \param bandwidth bandwidth used for the KDE
\param cummulative if \c true, a cummulative KDE is calculated
\see en.wikipedia.org/wiki/Kernel_density_estimation, \ref JKQTPlotterBasicJKQTPDatastoreStatistics
@@ -1763,6 +1765,8 @@ inline void jkqtpstatKDE1D(InputIt first, InputIt last, BinsInputIt binsFirst, B
\param binXRight last x-position, where to evaluate the KDE
\param[out] KDEXOut output iterator that receives x-positions of the KDE bins. Location of this value inside the bin range is defined by \a binXMode
\param[out] KDEYOut output iterator that receives counts/frequencies of the KDE bins
+ \param kernel the kernel function to use (e.g. jkqtpstatKernel1DGaussian() )
+ \param bandwidth bandwidth used for the KDE
\param cummulative if \c true, a cummulative KDE is calculated
\see en.wikipedia.org/wiki/Kernel_density_estimation, \ref JKQTPlotterBasicJKQTPDatastoreStatistics
@@ -1798,6 +1802,7 @@ inline void jkqtpstatKDE1D(InputIt first, InputIt last, double binXLeft, double
+
#endif // JKQTPSTATISTICSTOOLS_H_INCLUDED
diff --git a/lib/jkqtplotter/jkqtpbaseplotter.h b/lib/jkqtplotter/jkqtpbaseplotter.h
index 0e0f565337..93613b8b57 100644
--- a/lib/jkqtplotter/jkqtpbaseplotter.h
+++ b/lib/jkqtplotter/jkqtpbaseplotter.h
@@ -196,7 +196,7 @@ class JKQTP_LIB_EXPORT JKQTPPaintDeviceAdapter {
* accomodate the size of the key. If you select an \b inside key position the key will be plotted OVER the graph, i.e. the margins won't be changed
* Note that the margin change is internal and not visible in the class interface!
*
- * There is also a possibility to determine the size of the key automatically, so all text fits in. This is activted by the property keyAutosize ( \copybrief keyAutosize ). If this
+ * There is also a possibility to determine the size of the key automatically, so all text fits in. This is activted by the property keyAutosize ( \copybrief JKQTPKeyStyle::autosize ). If this
* is \c true the function getKeyExtent() has to check the width of every key item and take it into account when calculating the width and height of the
* key content. By default this feature is switched ON.
*
@@ -766,9 +766,9 @@ class JKQTP_LIB_EXPORT JKQTBasePlotter: public QObject {
/*! \copydoc JKQTBasePlotterStyle::plotFrameRounding */
double getPlotFrameRounding() const;
- /*! \copydoc plotLabelFontSize */
+ /*! \copydoc JKQTBasePlotterStyle::plotLabelFontSize */
double getPlotLabelFontSize() const;
- /*! \copydoc plotLabelFontName */
+ /*! \copydoc JKQTBasePlotterStyle::plotLabelFontName */
QString getplotLabelFontName() const;
/*! \copydoc plotLabel */
@@ -789,7 +789,7 @@ class JKQTP_LIB_EXPORT JKQTBasePlotter: public QObject {
/** \brief set the x- and y-positions of this JKQTPlotter in the grid-printing grid
*
- * \see setGridPrinting(), addGridPrintingPlotter(), clearGridPrintingPlotters(), setGridPrintingCurrentX(), setGridPrintingCurrentY() \ref JKQTPBASELOTTER_SYNCMULTIPLOT
+ * \see setGridPrinting(), addGridPrintingPlotter(), clearGridPrintingPlotters(), setGridPrintingCurrentX(), setGridPrintingCurrentY()
*/
void setGridPrintingCurrentPos(size_t x, size_t y);
diff --git a/lib/jkqtplotter/jkqtpdatastorage.h b/lib/jkqtplotter/jkqtpdatastorage.h
index 16426d4260..24a53c8899 100644
--- a/lib/jkqtplotter/jkqtpdatastorage.h
+++ b/lib/jkqtplotter/jkqtpdatastorage.h
@@ -219,7 +219,7 @@ enum class JKQTPDatastoreItemFormat {
* \section jkqtpdatastore_dataio Data Output
*
* JKQTPDatastore provides several functions that allow to store its contents into files:
- * - saveCSV
+ * - saveCSV()
* - saveSYLK()
* - saveMatlab()
* - saveDIF()
diff --git a/lib/jkqtplotter/jkqtpgraphsbasestylingmixins.h b/lib/jkqtplotter/jkqtpgraphsbasestylingmixins.h
index 84bfce9c16..4df3cad010 100644
--- a/lib/jkqtplotter/jkqtpgraphsbasestylingmixins.h
+++ b/lib/jkqtplotter/jkqtpgraphsbasestylingmixins.h
@@ -243,7 +243,6 @@ class JKQTP_LIB_EXPORT JKQTPGraphSymbolStyleMixin {
\param x x-coordinate of the symbol center
\param y y-coordinate of the symbol center
\param type type of the symbol
- \param symbolSize size of the symbol
*/
void plotStyledSymbol(JKQTBasePlotter* parent, JKQTPEnhancedPainter& painter, double x, double y, JKQTPGraphSymbols type) const;
/*! \brief plot a symbol at location x,y (in painter coordinates), using the current style
diff --git a/lib/jkqtplotter/jkqtpgraphscontour.h b/lib/jkqtplotter/jkqtpgraphscontour.h
index 5128674558..9a4432a283 100644
--- a/lib/jkqtplotter/jkqtpgraphscontour.h
+++ b/lib/jkqtplotter/jkqtpgraphscontour.h
@@ -99,7 +99,7 @@ class JKQTP_LIB_EXPORT JKQTPContourPlot: public JKQTPMathImage, public JKQTPGrap
void setIgnoreOnPlane(bool __value);
/*! \copydoc ignoreOnPlane */
bool getIgnoreOnPlane() const;
- /*! \copydoc numberOfLevels */
+ /*! \copydoc contourLevels */
int getNumberOfLevels() const;
/*! \copydoc contourColoringMode */
void setContourColoringMode(ContourColoringMode __value);
diff --git a/lib/jkqtplotter/jkqtpgraphsevaluatedfunction.h b/lib/jkqtplotter/jkqtpgraphsevaluatedfunction.h
index e98f40887e..4a35becef0 100644
--- a/lib/jkqtplotter/jkqtpgraphsevaluatedfunction.h
+++ b/lib/jkqtplotter/jkqtpgraphsevaluatedfunction.h
@@ -124,25 +124,25 @@ class JKQTP_LIB_EXPORT JKQTPXFunctionLineGraph: public JKQTPGraph, public JKQTPG
/*! \copydoc drawLine */
bool getDrawLine() const;
- /** \brief sets the property plotFunction ( \copybrief plotFunction ) to the specified \a __value.
+ /** \brief sets a functor to be plotted
*
- * \details Description of the parameter plotFunction is: \copydoc plotFunction
- * \see plotFunction for more information */
+ * \see plotFunction
+ */
virtual void setPlotFunctionFunctor (jkqtpPlotFunctionType && __value);
- /** \brief sets the property plotFunction ( \copybrief plotFunction ) to the specified \a __value.
+ /** \brief sets a functor to be plotted
*
- * \details Description of the parameter plotFunction is: \copydoc plotFunction
- * \see plotFunction for more information */
+ * \see plotFunction
+ */
virtual void setPlotFunctionFunctor (const jkqtpPlotFunctionType & __value);
- /** \brief sets the property plotFunction ( \copybrief plotFunction ) to the specified \a __value.
+ /** \brief sets a functor to be plotted
*
- * \details Description of the parameter plotFunction is: \copydoc plotFunction
- * \see plotFunction for more information */
+ * \see simplePlotFunction
+ */
virtual void setPlotFunctionFunctor (jkqtpSimplePlotFunctionType && __value);
- /** \brief sets the property plotFunction ( \copybrief plotFunction ) to the specified \a __value.
+ /** \brief sets a functor to be plotted
*
- * \details Description of the parameter plotFunction is: \copydoc plotFunction
- * \see plotFunction for more information */
+ * \see simplePlotFunction
+ */
virtual void setPlotFunctionFunctor (const jkqtpSimplePlotFunctionType & __value);
/*! \copydoc plotFunction */ \
virtual jkqtpPlotFunctionType getPlotFunctionFunctor () const;
@@ -204,27 +204,27 @@ class JKQTP_LIB_EXPORT JKQTPXFunctionLineGraph: public JKQTPGraph, public JKQTPG
void setDrawErrorLines(bool __value);
/*! \copydoc drawErrorLines */
bool getDrawErrorLines() const;
- /** \brief sets the property errorPlotFunction ( \copybrief errorPlotFunction ) to the specified \a __value.
+ /** \brief sets a functor to be used for calculating errors
*
- * \details Description of the parameter errorPlotFunction is: \copydoc errorPlotFunction
- * \see errorPlotFunction for more information */
+ * \see errorPlotFunction
+ */
virtual void setErrorPlotFunction (jkqtpPlotFunctionType && __value);
- /** \brief sets the property errorPlotFunction ( \copybrief errorPlotFunction ) to the specified \a __value.
+ /** \brief sets a functor to be used for calculating errors
*
- * \details Description of the parameter errorPlotFunction is: \copydoc errorPlotFunction
- * \see errorPlotFunction for more information */
+ * \see errorPlotFunction
+ */
virtual void setErrorPlotFunction (const jkqtpPlotFunctionType & __value);
/*! \copydoc errorPlotFunction */ \
virtual jkqtpPlotFunctionType getErrorPlotFunction () const;
- /** \brief sets the property errorPlotFunction ( \copybrief errorPlotFunction ) to the specified \a __value.
+ /** \brief sets a functor to be used for calculating errors
*
- * \details Description of the parameter errorPlotFunction is: \copydoc errorPlotFunction
- * \see errorPlotFunction for more information */
+ * \see errorSimplePlotFunction
+ */
virtual void setErrorPlotFunction (jkqtpSimplePlotFunctionType && __value);
- /** \brief sets the property errorPlotFunction ( \copybrief errorPlotFunction ) to the specified \a __value.
+ /** \brief sets a functor to be used for calculating errors
*
- * \details Description of the parameter errorPlotFunction is: \copydoc errorPlotFunction
- * \see errorPlotFunction for more information */
+ * \see errorSimplePlotFunction
+ */
virtual void setErrorPlotFunction (const jkqtpSimplePlotFunctionType & __value);
/*! \copydoc errorSimplePlotFunction */ \
virtual jkqtpSimplePlotFunctionType getErrorSimplePlotFunction () const;
diff --git a/lib/jkqtplotter/jkqtpgraphsgeometric.h b/lib/jkqtplotter/jkqtpgraphsgeometric.h
index c5c65ae274..61880615a7 100644
--- a/lib/jkqtplotter/jkqtpgraphsgeometric.h
+++ b/lib/jkqtplotter/jkqtpgraphsgeometric.h
@@ -44,6 +44,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoBaseLine: public JKQTPPlotObject, public JKQTPGra
\param color color of drawing
\param style line style of drawing
\param lineWidth lineWidth of drawing
+ \param parent the parent plotter object
*/
explicit JKQTPGeoBaseLine(QColor color, double lineWidth, Qt::PenStyle style=Qt::SolidLine, JKQTBasePlotter* parent=nullptr);
/*! \brief class contructor
@@ -51,6 +52,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoBaseLine: public JKQTPPlotObject, public JKQTPGra
\param color color of drawing
\param style line style of drawing
\param lineWidth lineWidth of drawing
+ \param parent the parent plotter object
*/
explicit JKQTPGeoBaseLine(QColor color, double lineWidth, Qt::PenStyle style, JKQTPlotter* parent);
/*! \brief class contructor
@@ -94,7 +96,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoBaseFilled: public JKQTPGeoBaseLine, public JKQTP
\param style line style of drawing
\param fillStyle filling style of the graph
\param lineWidth lineWidth of drawing
- \param parent the parent plotter class
+ \param parent the parent plotter object
*/
JKQTPGeoBaseFilled(QColor color, QColor fillColor, double lineWidth, Qt::PenStyle style=Qt::SolidLine, Qt::BrushStyle fillStyle=Qt::SolidPattern, JKQTBasePlotter* parent=nullptr);
/*! \brief class contructor
@@ -104,7 +106,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoBaseFilled: public JKQTPGeoBaseLine, public JKQTP
\param style line style of drawing
\param fillStyle filling style of the graph
\param lineWidth lineWidth of drawing
- \param parent the parent plotter class
+ \param parent the parent plotter object
*/
JKQTPGeoBaseFilled(QColor color, QColor fillColor, double lineWidth, Qt::PenStyle style, Qt::BrushStyle fillStyle, JKQTPlotter* parent);
/*! \brief class contructor
@@ -113,7 +115,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoBaseFilled: public JKQTPGeoBaseLine, public JKQTP
\param fillColor color of the filling in the drawing
\param style line style of drawing
\param lineWidth lineWidth of drawing
- \param parent the parent plotter class
+ \param parent the parent plotter object
*/
JKQTPGeoBaseFilled(QColor color, QColor fillColor, double lineWidth, Qt::PenStyle style, JKQTPlotter* parent);
/*! \brief class contructor
@@ -121,14 +123,14 @@ class JKQTP_LIB_EXPORT JKQTPGeoBaseFilled: public JKQTPGeoBaseLine, public JKQTP
\param color color of drawing
\param fillColor color of the filling in the drawing
\param lineWidth lineWidth of drawing
- \param parent the parent plotter class
+ \param parent the parent plotter object
*/
JKQTPGeoBaseFilled(QColor color, QColor fillColor, double lineWidth, JKQTPlotter* parent);
/*! \brief class contructor
\param color color of drawing
\param fillColor color of the filling in the drawing
- \param parent the parent plotter class
+ \param parent the parent plotter object
*/
JKQTPGeoBaseFilled(QColor color, QColor fillColor, JKQTPlotter* parent);
@@ -309,7 +311,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoLine: public JKQTPGeoBaseLine {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x1 x-coordinate of first point of line
\param y1 y-coordinate of first point of line
\param x2 x-coordinate of second point of line
@@ -317,12 +319,12 @@ class JKQTP_LIB_EXPORT JKQTPGeoLine: public JKQTPGeoBaseLine {
\param color color of line
\param lineWidth width of line
\param style line style
- \param parent the parent plotter class
+ \param parent the parent plotter object
*/
JKQTPGeoLine(JKQTBasePlotter* parent, double x1, double y1, double x2, double y2, QColor color, double lineWidth=1, Qt::PenStyle style=Qt::SolidLine);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x1 x-coordinate of first point of line
\param y1 y-coordinate of first point of line
\param x2 x-coordinate of second point of line
@@ -330,12 +332,12 @@ class JKQTP_LIB_EXPORT JKQTPGeoLine: public JKQTPGeoBaseLine {
\param color color of line
\param lineWidth width of line
\param style line style
- \param parent the parent plotter class
+ \param parent the parent plotter object
*/
JKQTPGeoLine(JKQTPlotter* parent, double x1, double y1, double x2, double y2, QColor color, double lineWidth=1, Qt::PenStyle style=Qt::SolidLine);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x1 x-coordinate of first point of line
\param y1 y-coordinate of first point of line
\param x2 x-coordinate of second point of line
@@ -345,7 +347,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoLine: public JKQTPGeoBaseLine {
JKQTPGeoLine(JKQTBasePlotter* parent, double x1, double y1, double x2, double y2);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x1 x-coordinate of first point of line
\param y1 y-coordinate of first point of line
\param x2 x-coordinate of second point of line
@@ -407,7 +409,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoInfiniteLine: public JKQTPGeoBaseLine {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of start point of line
\param y y-coordinate of start point of line
\param dx x-direction of the line
@@ -419,7 +421,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoInfiniteLine: public JKQTPGeoBaseLine {
JKQTPGeoInfiniteLine(JKQTBasePlotter* parent, double x, double y, double dx, double dy, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of start point of line
\param y y-coordinate of start point of line
\param dx x-direction of the line
@@ -485,7 +487,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPolyLines: public JKQTPGeoBaseLine {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param points points on the polygon
\param color color of line
\param lineWidth width of line
@@ -494,7 +496,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPolyLines: public JKQTPGeoBaseLine {
JKQTPGeoPolyLines(JKQTBasePlotter* parent, const QVector& points, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param points points on the polygon
\param color color of line
\param lineWidth width of line
@@ -503,7 +505,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPolyLines: public JKQTPGeoBaseLine {
JKQTPGeoPolyLines(JKQTPlotter* parent, const QVector& points, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param color color of line
\param lineWidth width of line
\param style line style
@@ -511,7 +513,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPolyLines: public JKQTPGeoBaseLine {
JKQTPGeoPolyLines(JKQTBasePlotter* parent, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param color color of line
\param lineWidth width of line
\param style line style
@@ -552,7 +554,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoRectangle: public JKQTPGeoBaseFilled {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of rectangle
\param y y-coordinate of center of rectangle
\param width width of rectangle
@@ -566,7 +568,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoRectangle: public JKQTPGeoBaseFilled {
JKQTPGeoRectangle(JKQTBasePlotter* parent, double x, double y, double width, double height, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of rectangle
\param y y-coordinate of center of rectangle
\param width width of rectangle
@@ -580,7 +582,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoRectangle: public JKQTPGeoBaseFilled {
JKQTPGeoRectangle(JKQTPlotter* parent, double x, double y, double width, double height, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of rectangle
\param y y-coordinate of center of rectangle
\param width width of rectangle
@@ -595,7 +597,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoRectangle: public JKQTPGeoBaseFilled {
JKQTPGeoRectangle(JKQTBasePlotter* parent, double x, double y, double width, double height, double angle, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of rectangle
\param y y-coordinate of center of rectangle
\param width width of rectangle
@@ -610,7 +612,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoRectangle: public JKQTPGeoBaseFilled {
JKQTPGeoRectangle(JKQTPlotter* parent, double x, double y, double width, double height, double angle, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param bottomleft bottom left corner of rectangle
\param topright top right corner of rectangle
\param color color of line
@@ -622,7 +624,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoRectangle: public JKQTPGeoBaseFilled {
JKQTPGeoRectangle(JKQTBasePlotter* parent, QPointF bottomleft, QPointF topright, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param bottomleft bottom left corner of rectangle
\param topright top right corner of rectangle
\param color color of line
@@ -694,7 +696,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPolygon: public JKQTPGeoBaseFilled {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param points points on the polygon
\param color color of line
\param lineWidth width of line
@@ -706,7 +708,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPolygon: public JKQTPGeoBaseFilled {
JKQTPGeoPolygon(JKQTBasePlotter* parent, const QVector& points, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param points points on the polygon
\param color color of line
\param lineWidth width of line
@@ -718,7 +720,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPolygon: public JKQTPGeoBaseFilled {
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param color color of line
\param lineWidth width of line
\param style line style
@@ -729,7 +731,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPolygon: public JKQTPGeoBaseFilled {
JKQTPGeoPolygon(JKQTBasePlotter* parent, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param color color of line
\param lineWidth width of line
\param style line style
@@ -776,7 +778,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoEllipse: public JKQTPGeoRectangle {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of ellipse
\param y y-coordinate of center of ellipse
\param width width of ellipse (2 * half axis)
@@ -791,7 +793,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoEllipse: public JKQTPGeoRectangle {
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of ellipse
\param y y-coordinate of center of ellipse
\param width width of ellipse (2 * half axis)
@@ -805,7 +807,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoEllipse: public JKQTPGeoRectangle {
JKQTPGeoEllipse(JKQTPlotter* parent, double x, double y, double width, double height, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of rectangle
\param y y-coordinate of center of rectangle
\param width width of rectangle
@@ -820,7 +822,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoEllipse: public JKQTPGeoRectangle {
JKQTPGeoEllipse(JKQTBasePlotter* parent, double x, double y, double width, double height, double angle, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of rectangle
\param y y-coordinate of center of rectangle
\param width width of rectangle
@@ -835,7 +837,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoEllipse: public JKQTPGeoRectangle {
JKQTPGeoEllipse(JKQTPlotter* parent, double x, double y, double width, double height, double angle, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param bottomleft bottom left corner of rectangle
\param topright top right corner of rectangle
\param color color of line
@@ -847,7 +849,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoEllipse: public JKQTPGeoRectangle {
JKQTPGeoEllipse(JKQTBasePlotter* parent, QPointF bottomleft, QPointF topright, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param bottomleft bottom left corner of rectangle
\param topright top right corner of rectangle
\param color color of line
@@ -882,7 +884,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoArc: public JKQTPGeoBaseLine {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of ellipse
\param y y-coordinate of center of ellipse
\param width width of ellipse (2 * half axis)
@@ -897,7 +899,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoArc: public JKQTPGeoBaseLine {
JKQTPGeoArc(JKQTBasePlotter* parent, double x, double y, double width, double height, double angleStart, double angleStop, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of ellipse
\param y y-coordinate of center of ellipse
\param width width of ellipse (2 * half axis)
@@ -991,7 +993,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPie: public JKQTPGeoEllipse {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of ellipse
\param y y-coordinate of center of ellipse
\param width width of ellipse (2 * half axis)
@@ -1007,7 +1009,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoPie: public JKQTPGeoEllipse {
JKQTPGeoPie(JKQTBasePlotter* parent, double x, double y, double width, double height, double angleStart, double angleStop, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of ellipse
\param y y-coordinate of center of ellipse
\param width width of ellipse (2 * half axis)
@@ -1060,7 +1062,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoChord: public JKQTPGeoPie {
public:
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of ellipse
\param y y-coordinate of center of ellipse
\param width width of ellipse (2 * half axis)
@@ -1076,7 +1078,7 @@ class JKQTP_LIB_EXPORT JKQTPGeoChord: public JKQTPGeoPie {
JKQTPGeoChord(JKQTBasePlotter* parent, double x, double y, double width, double height, double angleStart, double angleStop, QColor color=QColor("black"), double lineWidth=1, Qt::PenStyle style=Qt::SolidLine, QColor fillColor=QColor("transparent"), Qt::BrushStyle fillStyle=Qt::SolidPattern);
/*! \brief class constructor
- \param parent the parent plotter class
+ \param parent the parent plotter object
\param x x-coordinate of center of ellipse
\param y y-coordinate of center of ellipse
\param width width of ellipse (2 * half axis)
diff --git a/lib/jkqtplotter/jkqtpgraphsimage.h b/lib/jkqtplotter/jkqtpgraphsimage.h
index 61b91c160e..05bf86ab0d 100644
--- a/lib/jkqtplotter/jkqtpgraphsimage.h
+++ b/lib/jkqtplotter/jkqtpgraphsimage.h
@@ -259,11 +259,11 @@ class JKQTP_LIB_EXPORT JKQTPMathImageBase: public JKQTPImageBase {
/*! \copydoc modifierMode */
ModifierMode getModifierMode() const;
- /** \brief sets dataModifier (\copybrief dataModifier) and datatypeModifier (\copybrief datatypeModifier) */
+ /** \brief sets dataModifier (\copybrief dataModifier ) and datatypeModifier (\copybrief datatypeModifier ) */
virtual void setDataModifier(void* data, DataType datatype);
- /** \brief sets data (\copybrief data) and datatype (\copybrief datatype), as well as the size of data (Nx: \copybrief Nx and Ny: \copybrief Ny) */
+ /** \brief sets data (\copybrief data ) and datatype (\copybrief datatype ), as well as the size of data (Nx: \copybrief Nx and Ny: \copybrief Ny ) */
virtual void setData(void* data, int Nx, int Ny, DataType datatype);
- /** \brief sets data (\copybrief data), as well as the size of data (Nx: \copybrief Nx and Ny: \copybrief Ny) */
+ /** \brief sets data (\copybrief data ), as well as the size of data (Nx: \copybrief Nx and Ny: \copybrief Ny ) */
virtual void setData(void* data, int Nx, int Ny);
/** \brief determine min/max data value of the image */
virtual void getDataMinMax(double& imin, double& imax);
diff --git a/lib/jkqtplotter/jkqtpgraphsimagergb.h b/lib/jkqtplotter/jkqtpgraphsimagergb.h
index a6d832c29f..7c5c3088c5 100644
--- a/lib/jkqtplotter/jkqtpgraphsimagergb.h
+++ b/lib/jkqtplotter/jkqtpgraphsimagergb.h
@@ -454,7 +454,6 @@ class JKQTP_LIB_EXPORT JKQTPColumnRGBMathImage: public JKQTPRGBMathImage {
* \param width width of the image in system coordinates
* \param height height of the image in system coordinates
* \param imageRColumn column for red channel to be plotted
- * \param palette color palette to use for the plotting
* \param parent parent plotter object
*
*/
@@ -467,7 +466,6 @@ class JKQTP_LIB_EXPORT JKQTPColumnRGBMathImage: public JKQTPRGBMathImage {
* \param height height of the image in system coordinates
* \param imageRColumn column for red channel to be plotted
* \param imageGColumn column for green channel to be plotted
- * \param palette color palette to use for the plotting
* \param parent parent plotter object
*
*/
@@ -481,7 +479,6 @@ class JKQTP_LIB_EXPORT JKQTPColumnRGBMathImage: public JKQTPRGBMathImage {
* \param imageRColumn column for red channel to be plotted
* \param imageGColumn column for green channel to be plotted
* \param imageBColumn column for blue channel to be plotted
- * \param palette color palette to use for the plotting
* \param parent parent plotter object
*
*/
@@ -508,7 +505,6 @@ class JKQTP_LIB_EXPORT JKQTPColumnRGBMathImage: public JKQTPRGBMathImage {
* \param width width of the image in system coordinates
* \param height height of the image in system coordinates
* \param imageRColumn column for red channel to be plotted
- * \param palette color palette to use for the plotting
* \param parent parent plotter object
*
*/
@@ -521,7 +517,6 @@ class JKQTP_LIB_EXPORT JKQTPColumnRGBMathImage: public JKQTPRGBMathImage {
* \param height height of the image in system coordinates
* \param imageRColumn column for red channel to be plotted
* \param imageGColumn column for green channel to be plotted
- * \param palette color palette to use for the plotting
* \param parent parent plotter object
*
*/
@@ -535,7 +530,6 @@ class JKQTP_LIB_EXPORT JKQTPColumnRGBMathImage: public JKQTPRGBMathImage {
* \param imageRColumn column for red channel to be plotted
* \param imageGColumn column for green channel to be plotted
* \param imageBColumn column for blue channel to be plotted
- * \param palette color palette to use for the plotting
* \param parent parent plotter object
*
*/
diff --git a/lib/jkqtplotter/jkqtpgraphsstatisticsadaptors.h b/lib/jkqtplotter/jkqtpgraphsstatisticsadaptors.h
index ac248c400d..5f8aa81d16 100644
--- a/lib/jkqtplotter/jkqtpgraphsstatisticsadaptors.h
+++ b/lib/jkqtplotter/jkqtpgraphsstatisticsadaptors.h
@@ -29,10 +29,10 @@
#define JKQTPGRAPHSSTATISTICSADAPTORS_H_INCLUDED
/*! \brief add a JKQTPBoxplotHorizontalElement to the given plotter, where the boxplot values are calculated from the data range \a first ... \a last
- \ingroup jkqtptools_math_statistics
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_adaptors
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param boxposY y-coordinate of the boxplot
@@ -74,10 +74,10 @@ inline JKQTPBoxplotHorizontalElement* jkqtpstatAddHBoxplot(JKQTBasePlotter* plot
/*! \brief add a JKQTPBoxplotVerticalElement to the given plotter, where the boxplot values are calculated from the data range \a first ... \a last
- \ingroup jkqtptools_math_statistics
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_adaptors
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param boxposX x-coordinate of the boxplot
@@ -120,10 +120,10 @@ inline JKQTPBoxplotVerticalElement* jkqtpstatAddVBoxplot(JKQTBasePlotter* plotte
/*! \brief add a JKQTPBoxplotHorizontalElement and a JKQTPSingleColumnSymbolsGraph for outliers to the given plotter, where the boxplot values are calculated from the data range \a first ... \a last
- \ingroup jkqtptools_math_statistics
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_adaptors
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param boxposY y-coordinate of the outliers (and the boxplot)
@@ -179,10 +179,11 @@ inline std::pair
/*! \brief add a JKQTPBoxplotVerticalElement and a JKQTPSingleColumnSymbolsGraph for outliers to the given plotter, where the boxplot values are calculated from the data range \a first ... \a last
- \ingroup jkqtptools_math_statistics
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors
+
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param boxposX x-coordinate of the outliers (and the boxplot)
@@ -238,10 +239,11 @@ inline std::pair jk
/*! \brief calculate an autoranged histogram and add a JKQTPBarVerticalGraph to the given plotter, where the histogram is calculated from the data range \a first ... \a last, bins defined by their number
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param bins number of bins in the resulting histogram
@@ -273,10 +275,11 @@ inline JKQTPBarVerticalGraph* jkqtpstatAddHHistogram1DAutoranged(JKQTBasePlotter
/*! \brief calculate an autoranged histogram and add a JKQTPBarVerticalGraph to the given plotter, where the histogram is calculated from the data range \a first ... \a last, bins defined by their width
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param binWidth width of the bins
@@ -307,11 +310,12 @@ inline JKQTPBarVerticalGraph* jkqtpstatAddHHistogram1DAutoranged(JKQTBasePlotter
/*! \brief calculate an autoranged histogram and add a JKQTPBarVerticalGraph to the given plotter, where the histogram is calculated from the data range \a first ... \a last, bins defined by their width
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
\tparam BinsInputIt standard iterator type of \a binsFirst and \a binsLast.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param binsFirst iterator pointing to the first item in the set of histogram bins
@@ -344,10 +348,11 @@ inline JKQTPBarVerticalGraph* jkqtpstatAddHHistogram1D(JKQTBasePlotter* plotter,
/*! \brief calculate an autoranged histogram and add a JKQTPBarHorizontalGraph to the given plotter, where the histogram is calculated from the data range \a first ... \a last, bins defined by their number
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param bins number of bins in the resulting histogram
@@ -379,10 +384,11 @@ inline JKQTPBarHorizontalGraph* jkqtpstatAddVHistogram1DAutoranged(JKQTBasePlott
/*! \brief calculate an autoranged histogram and add a JKQTPBarHorizontalGraph to the given plotter, where the histogram is calculated from the data range \a first ... \a last, bins defined by their width
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param binWidth width of the bins
@@ -413,11 +419,12 @@ inline JKQTPBarHorizontalGraph* jkqtpstatAddVHistogram1DAutoranged(JKQTBasePlott
/*! \brief calculate an autoranged histogram and add a JKQTPBarHorizontalGraph to the given plotter, where the histogram is calculated from the data range \a first ... \a last, bins defined by their width
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
\tparam BinsInputIt standard iterator type of \a binsFirst and \a binsLast.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param binsFirst iterator pointing to the first item in the set of histogram bins
@@ -460,10 +467,11 @@ inline JKQTPBarHorizontalGraph* jkqtpstatAddVHistogram1D(JKQTBasePlotter* plotte
/*! \brief calculate an autoranged KDE and add a JKQTPXYLineGraph to the given plotter, where the KDE is calculated from the data range \a first ... \a last, bins defined by their number
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param Nout number of points in the resulting KDE
@@ -498,10 +506,11 @@ inline JKQTPXYLineGraph* jkqtpstatAddHKDE1DAutoranged(JKQTBasePlotter* plotter,
/*! \brief calculate an autoranged KDE and add a JKQTPXYLineGraph to the given plotter, where the KDE is calculated from the data range \a first ... \a last, bins defined by their width
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param binWidth width of the bins
@@ -535,11 +544,12 @@ inline JKQTPXYLineGraph* jkqtpstatAddHKDE1DAutoranged(JKQTBasePlotter* plotter,
/*! \brief calculate an autoranged KDE and add a JKQTPXYLineGraph to the given plotter, where the KDE is calculated from the data range \a first ... \a last, bins defined by their width
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
\tparam BinsInputIt standard iterator type of \a binsFirst and \a binsLast.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param binsFirst iterator pointing to the first item in the set of KDE bins
@@ -574,10 +584,11 @@ inline JKQTPXYLineGraph* jkqtpstatAddHKDE1D(JKQTBasePlotter* plotter, InputIt fi
}
/*! \brief calculate an autoranged KDE and add a JKQTPXYLineGraph to the given plotter, where the KDE is calculated from the data range \a first ... \a last, evaluation positions are given by the range \a binXLeft ... \a binXRight (in steps of \a binxDelta )
- \ingroup jkqtptools_math_statistics_1dhist
- \ingroup jkqtplotter_statgraphs
+ \ingroup jkqtptools_math_statistics_adaptors_1dhist
+
\tparam InputIt standard iterator type of \a first and \a last.
+ \param plotter the plotter to which to add the resulting graph
\param first iterator pointing to the first item in the dataset to use \f$ X_1 \f$
\param last iterator pointing behind the last item in the dataset to use \f$ X_N \f$
\param binXLeft first x-position, where to evaluate the KDE
diff --git a/sharedlib/jkqtfastplotterlib/jkqtfastplotterlib.pro b/sharedlib/jkqtfastplotterlib/jkqtfastplotterlib.pro
index b99661b757..0808641991 100644
--- a/sharedlib/jkqtfastplotterlib/jkqtfastplotterlib.pro
+++ b/sharedlib/jkqtfastplotterlib/jkqtfastplotterlib.pro
@@ -14,3 +14,6 @@ win32 {
include(../../lib/jkqtfastplotter.pri)
include(../../lib/jkqtpcommon.pri)
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/sharedlib/jkqtmathtextlib/jkqtmathtextlib.pro b/sharedlib/jkqtmathtextlib/jkqtmathtextlib.pro
index 9e397cc29b..2852f42980 100644
--- a/sharedlib/jkqtmathtextlib/jkqtmathtextlib.pro
+++ b/sharedlib/jkqtmathtextlib/jkqtmathtextlib.pro
@@ -14,3 +14,6 @@ win32 {
include(../../lib/jkqtmathtext.pri)
include(../../lib/jkqtpcommon.pri)
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/sharedlib/jkqtpcommonlib/jkqtpcommonlib.pro b/sharedlib/jkqtpcommonlib/jkqtpcommonlib.pro
index 8154b81b5e..00384c1b5e 100644
--- a/sharedlib/jkqtpcommonlib/jkqtpcommonlib.pro
+++ b/sharedlib/jkqtpcommonlib/jkqtpcommonlib.pro
@@ -13,3 +13,6 @@ win32 {
}
include(../../lib/jkqtpcommon.pri)
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/sharedlib/jkqtplotterlib/jkqtplotterlib.pro b/sharedlib/jkqtplotterlib/jkqtplotterlib.pro
index 5f5cd8380a..0311c5bec7 100644
--- a/sharedlib/jkqtplotterlib/jkqtplotterlib.pro
+++ b/sharedlib/jkqtplotterlib/jkqtplotterlib.pro
@@ -12,6 +12,10 @@ win32 {
DEFINES += JKQTP_LIB_EXPORT_LIBRARY
}
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
+
+
include(../../lib/jkqtplotter.pri)
include(../../lib/jkqtpcommon.pri)
include(../../lib/jkqtmathtext.pri)
diff --git a/staticlib/jkqtfastplotterlib/jkqtfastplotterlib.pro b/staticlib/jkqtfastplotterlib/jkqtfastplotterlib.pro
index 95a56b0c7a..e41c996c2f 100644
--- a/staticlib/jkqtfastplotterlib/jkqtfastplotterlib.pro
+++ b/staticlib/jkqtfastplotterlib/jkqtfastplotterlib.pro
@@ -9,3 +9,6 @@ CONFIG += create_prl
include(../../lib/jkqtfastplotter.pri)
include(../../lib/jkqtpcommon.pri)
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/staticlib/jkqtmathtextlib/jkqtmathtextlib.pro b/staticlib/jkqtmathtextlib/jkqtmathtextlib.pro
index aef93bbc7d..69b2f47555 100644
--- a/staticlib/jkqtmathtextlib/jkqtmathtextlib.pro
+++ b/staticlib/jkqtmathtextlib/jkqtmathtextlib.pro
@@ -9,3 +9,6 @@ CONFIG += create_prl
include(../../lib/jkqtmathtext.pri)
include(../../lib/jkqtpcommon.pri)
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/staticlib/jkqtpcommonlib/jkqtpcommonlib.pro b/staticlib/jkqtpcommonlib/jkqtpcommonlib.pro
index 3247558c54..89f6ebb467 100644
--- a/staticlib/jkqtpcommonlib/jkqtpcommonlib.pro
+++ b/staticlib/jkqtpcommonlib/jkqtpcommonlib.pro
@@ -8,3 +8,6 @@ CONFIG += staticlib
CONFIG += create_prl
include(../../lib/jkqtpcommon.pri)
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
diff --git a/staticlib/jkqtplotterlib/jkqtplotterlib.pro b/staticlib/jkqtplotterlib/jkqtplotterlib.pro
index b2cd517fab..ce00e09b6e 100644
--- a/staticlib/jkqtplotterlib/jkqtplotterlib.pro
+++ b/staticlib/jkqtplotterlib/jkqtplotterlib.pro
@@ -13,3 +13,6 @@ include(../../lib/jkqtpcommon.pri)
include(../../lib/jkqtplotter.pri)
include(../../lib/jkqtmathtext.pri)
include(../../lib/jkqtfastplotter.pri)
+
+win32-msvc*: DEFINES += _USE_MATH_DEFINES
+win32-msvc*: DEFINES += NOMINMAX
|
diff --git a/lib/jkqtfastplotter/jkqtfastplotter.h b/lib/jkqtfastplotter/jkqtfastplotter.h
index e9d66a9d93..dfdbcbacd5 100644
--- a/lib/jkqtfastplotter/jkqtfastplotter.h
+++ b/lib/jkqtfastplotter/jkqtfastplotter.h
@@ -1387,12 +1387,12 @@ class JKQTP_LIB_EXPORT JKQTFPXRangePlot: public JKQTFPPlot {
/*! \brief class constructor
\param parent parent widget
- \param N number of datapoints in the plot
- \param x points to the x values in the plot
- \param y points to the y values in the plot
+ \param xmin range start
+ \param xmax range end
\param color color of the plot
\param style style of the graph
\param width width of the plot (in pt)
+ \param fillStyle fill style of the range
*/
JKQTFPXRangePlot(JKQTFastPlotter* parent, double xmin, double xmax, QColor color=QColor("red"), Qt::PenStyle style=Qt::SolidLine, double width=1, Qt::BrushStyle fillStyle=Qt::NoBrush) ;
@@ -1551,12 +1551,12 @@ class JKQTP_LIB_EXPORT JKQTFPYRangePlot: public JKQTFPPlot {
/*! \brief class constructor
\param parent parent widget
- \param N number of datapoints in the plot
- \param x points to the x values in the plot
- \param y points to the y values in the plot
+ \param ymin range start
+ \param ymax range end
\param color color of the plot
\param style style of the graph
\param width width of the plot (in pt)
+ \param fillStyle fill style of the range
*/
JKQTFPYRangePlot(JKQTFastPlotter* parent, double ymin, double ymax, QColor color=QColor("red"), Qt::PenStyle style=Qt::SolidLine, double width=1, Qt::BrushStyle fillStyle=Qt::NoBrush) ;
@@ -1787,7 +1787,8 @@ class JKQTP_LIB_EXPORT JKQTFPQImagePlot: public JKQTFPPlot {
/*!
\brief An enum for selecting the palette for coloring
\ingroup jkqtfastplotter
- \details Here, the color palettes are illustrated (left is the color for the minimum and right for the maximum).
+
+ Here, the color palettes are illustrated (left is the color for the minimum and right for the maximum).
*/
enum JKQTFPColorPalette {
JKQTFP_RED=0, /*!< \image html palettes/palette_red.png */
@@ -1811,17 +1812,18 @@ enum JKQTFPColorPalette {
JKQTFP_CYAN=18 /*!< \image html palettes/palette_cyan.png */
};
/*!datatype for an image plotpalette for coloring
\ingroup jkqtfastplotter
- \details Here, the color palettes are illustrated (left is the color for the minimum and right for the maximum).
+
+ Here, the color palettes are illustrated (left is the color for the minimum and right for the maximum).
*/
enum JKQTFPImageFormat {
- JKQTFP_uint8=0, /*!< \image 8 bit int */
- JKQTFP_uint16=1, /*!< \image 16 bit int */
- JKQTFP_uint32=2, /*!< \image 32 bit int */
- JKQTFP_float=3, /*!< \image float */
- JKQTFP_double=4, /*!< \image double */
- JKQTFP_int64=5 /*!< \image 64 bit signed int */
+ JKQTFP_uint8=0, /*!< \brief 8 bit int */
+ JKQTFP_uint16=1, /*!< \brief 16 bit int */
+ JKQTFP_uint32=2, /*!< \brief 32 bit int */
+ JKQTFP_float=3, /*!< \brief float */
+ JKQTFP_double=4, /*!< \brief double */
+ JKQTFP_int64=5 /*!< \brief 64 bit signed int */
};
@@ -2797,7 +2799,9 @@ class JKQTP_LIB_EXPORT JKQTFPRGBImageOverlayPlot: public JKQTFPPlot {
/*! \brief sets the properties imageRed and imageFormatRed to the specified \a __value and \a __value2.
- \details Description of the parameter imageRed is: \copydoc JKQTFPRGBImageOverlayPlot::imageRed \details Description of the parameter imageFormatRed is: \copydoc JKQTFPRGBImageOverlayPlot::imageFormatRed */
+
+ \see imageRed, imageFormatRed
+ */
inline void setImageRed (void* __value, JKQTFPImageFormat __value2)
{
bool set=false;
@@ -2817,8 +2821,10 @@ class JKQTP_LIB_EXPORT JKQTFPRGBImageOverlayPlot: public JKQTFPPlot {
inline void* getImageRed () const { return this->imageRed; }
/*! \copydoc imageFormatRed */
inline JKQTFPImageFormat getImageFormatRed () const { return this->imageFormatRed; }
- /*! \brief sets the properties imageGreen and imageFormatGreen to the specified \a __value and \a __value2.
- \details Description of the parameter imageGreen is: \copydoc JKQTFPRGBImageOverlayPlot::imageGreen \details Description of the parameter imageFormatGreen is: \copydoc JKQTFPRGBImageOverlayPlot::imageFormatGreen */
+ /*! \brief sets the properties imageGreen and imageFormatGreen to the specified \a __value and \a __value2.
+
+ \see imageGreen, imageFormatGreen
+ */
inline void setImageGreen (void* __value, JKQTFPImageFormat __value2)
{
bool set=false;
@@ -2838,9 +2844,11 @@ class JKQTP_LIB_EXPORT JKQTFPRGBImageOverlayPlot: public JKQTFPPlot {
inline void* getImageGreen () const { return this->imageGreen; }
/*! \copydoc imageFormatGreen */
inline JKQTFPImageFormat getImageFormatGreen () const { return this->imageFormatGreen; }
- /*! \brief sets the properties imageBlue and imageFormatBlue to the specified \a __value and \a __value2.
- \details Description of the parameter imageBlue is: \copydoc JKQTFPRGBImageOverlayPlot::imageBlue \details Description of the parameter imageFormatBlue is: \copydoc JKQTFPRGBImageOverlayPlot::imageFormatBlue */
- inline void setImageBlue (void* __value, JKQTFPImageFormat __value2)
+ /*! \brief sets the properties imageBlue and imageFormatBlue to the specified \a __value and \a __value2.
+
+ \see imageBlue, imageFormatBlue
+ */
+ inline void setImageBlue (void* __value, JKQTFPImageFormat __value2)
{
bool set=false;
if (this->imageBlue != __value) {
@@ -1811,17 +1812,18 @@ enum JKQTFPColorPalette {
JKQTFP_CYAN=18 /*!< \image html palettes/palette_cyan.png */
};
-/*!datatype for an image plotpalette for coloring
+/*! \brief datatype for an image plotpalette for coloring
\ingroup jkqtfastplotter